@@ -1,6 +1,6 @@
 ;;; hkl-default.el --- Hkl specific emacsen startup code.
 
-;; Copyright (C) 2003-2016 Synchrotron SOLEIL
+;; Copyright (C) 2003-2018 Synchrotron SOLEIL
 ;;                         L'Orme des Merisiers Saint-Aubin
 ;;                         BP 48 91192 GIF-sur-YVETTE CEDEX
 
@@ -43,7 +43,8 @@
    (quote
     ((latex . t)
      (python . t)
-     (emacs-lisp . t))))
+     (emacs-lisp . t)
+     (gnuplot . t))))
  '(org-confirm-babel-evaluate nil)
  '(org-latex-listings (quote minted))
  '(org-latex-minted-langs
@@ -58,6 +59,36 @@
    (quote
     ("pdflatex -interaction nonstopmode --shell-escape -output-directory %o %f" "pdflatex -interaction nonstopmode --shell-escape -output-directory %o %f" "pdflatex -interaction nonstopmode --shell-escape -output-directory %o %f")))
  '(org-export-with-sub-superscripts nil)
- '(org-src-fontify-natively t))
+ '(org-src-fontify-natively t)
+ '(org-publish-project-alist
+   (quote
+    (("hkl"
+     :base-directory "."
+     :base-extension "org"
+     :publishing-directory "/ssh:picca@people.debian.org:~/public_html/hkl/"
+     :publishing-function org-html-publish-to-html
+     :headline-levels 3
+     :section-numbers t
+     :with-toc t
+     :html-head "<link rel=\"stylesheet\"
+                       href=\"../css/style.css\" type=\"text/css\"/>"
+     :html-preamble t)
+
+    ("images"
+     :base-directory "figures/"
+     :base-extension "svg\\|jpg\\|gif\\|png"
+     :publishing-directory "/ssh:picca@people.debian.org:~/public_html/hkl/figures/"
+     :publishing-function org-publish-attachment)
+
+    ("css"
+     :base-directory "css/"
+     :base-extension "css"
+     :publishing-directory "/ssh:picca@people.debian.org:~/public_html/hkl/css/"
+     :publishing-function org-publish-attachment)
+
+    ))))
+
+(require 'ox-publish)
+
 (provide 'hkl-default)
 ;;; hkl-default ends here
