@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2016 Synchrotron SOLEIL
+ * Copyright (C) 2003-2018 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -30,6 +30,8 @@
 G_BEGIN_DECLS
 
 typedef struct _HklAxis HklAxis;
+typedef struct _HklRotationWithOrigin HklRotationWithOrigin;
+typedef struct _HklTranslation HklTranslation;
 
 struct _HklAxis {
 	HklParameter parameter;
@@ -37,7 +39,28 @@ struct _HklAxis {
 	HklQuaternion q; /* internal */
 };
 
-extern HklParameter *hkl_parameter_new_axis(const char* name, HklVector const *axis_v, const HklUnit *punit);
+struct _HklRotationWithOrigin {
+	HklAxis axis;
+	HklVector origin;
+};
+
+struct _HklTranslation {
+	HklParameter parameter;
+	HklVector axis_v;
+};
+
+extern HklParameter *hkl_parameter_new_rotation(const char* name,
+						HklVector const *axis_v,
+						const HklUnit *punit);
+
+extern HklParameter *hkl_parameter_new_rotation_with_origin(const char* name,
+							    const HklVector *axis_v,
+							    const HklVector *origin,
+							    const HklUnit *punit);
+
+extern HklParameter *hkl_parameter_new_translation(const char *name,
+						   const HklVector *axis_v,
+						   const HklUnit *punit);
 
 G_END_DECLS
 
