@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2016 Synchrotron SOLEIL
+ * Copyright (C) 2003-2018 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -99,19 +99,19 @@ static const char* hkl_geometry_soleil_sirius_turret_axes[] = {BASEPITCH, THETAH
 
 static HklGeometry *hkl_geometry_new_soleil_sirius_turret(const HklFactory *factory)
 {
-	HklGeometry *self = hkl_geometry_new(factory);
+	HklGeometry *self = hkl_geometry_new(factory, &hkl_geometry_operations_defaults);
 	HklHolder *h;
 
 	h = hkl_geometry_add_holder(self);
-	hkl_holder_add_rotation_axis_with_punit(h, BASEPITCH, 0, 1, 0, &hkl_unit_angle_mrad);
-	hkl_holder_add_rotation_axis(h, THETAH, 0, 0, -1);
-	hkl_holder_add_rotation_axis(h, ALPHAY, 0, 1, 0);
-	hkl_holder_add_rotation_axis(h, ALPHAX, 1, 0, 0);
+	hkl_holder_add_rotation(h, BASEPITCH, 0, 1, 0, &hkl_unit_angle_mrad);
+	hkl_holder_add_rotation(h, THETAH, 0, 0, -1, &hkl_unit_angle_deg);
+	hkl_holder_add_rotation(h, ALPHAY, 0, 1, 0, &hkl_unit_angle_deg);
+	hkl_holder_add_rotation(h, ALPHAX, 1, 0, 0, &hkl_unit_angle_deg);
 
 	h = hkl_geometry_add_holder(self);
-	hkl_holder_add_rotation_axis_with_punit(h, BASEPITCH, 0, 1, 0, &hkl_unit_angle_mrad);
-	hkl_holder_add_rotation_axis(h, DELTA, 0, 0, -1);
-	hkl_holder_add_rotation_axis(h, GAMMA, 0, -1, 0);
+	hkl_holder_add_rotation(h, BASEPITCH, 0, 1, 0, &hkl_unit_angle_mrad);
+	hkl_holder_add_rotation(h, DELTA, 0, 0, -1, &hkl_unit_angle_deg);
+	hkl_holder_add_rotation(h, GAMMA, 0, -1, 0, &hkl_unit_angle_deg);
 
 	return self;
 }
