@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2016 Synchrotron SOLEIL
+ * Copyright (C) 2003-2018 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -50,23 +50,20 @@
  * else create a new on and add it to the list.
  * die if try to add an axis with the same name but a different axis_v
  */
-static size_t hkl_geometry_add_rotation(HklGeometry *self,
-					const char *name, const HklVector *axis_v,
-					const HklUnit *punit)
+static size_t hkl_geometry_add_axis(HklGeometry *self, const HklParameter *axis)
 {
 	uint i = 0;
 	HklParameter **parameter;
 
 	/* check if an axis with the same name is on the axis list */
 	darray_foreach(parameter, self->axes){
-		HklAxis *axis = container_of(*parameter, HklAxis, parameter);
-		if(!strcmp((*parameter)->name, name)){
-			if (hkl_vector_cmp(&axis->axis_v,
-					   axis_v)){
-				fprintf(stderr, "can not add two axis with the same name \"%s\" but different axes <%f, %f, %f> != <%f, %f, %f> into an HklAxes.",
-					name,
-					axis->axis_v.data[0], axis->axis_v.data[1], axis->axis_v.data[2],
-					axis_v->data[0], axis_v->data[1], axis_v->data[2]);
+		if(!strcmp((*parameter)->name, axis->name)){
+			if (hkl_parameter_transformation_cmp(*parameter, axis)){
+				fprintf(stderr,
+					"can not add two axis with the same name \"%s\" but not compatible transformation",
+					axis->name);
+				hkl_parameter_fprintf(stderr, *parameter);
+				hkl_parameter_fprintf(stderr, axis);
 				exit(128);
 			}else{
 				return i;
@@ -76,7 +73,7 @@ static size_t hkl_geometry_add_rotation(HklGeometry *self,
 	}
 
 	/* no so create and add it to the list */
-	darray_append(self->axes, hkl_parameter_new_axis(name, axis_v, punit));
+	darray_append(self->axes, hkl_parameter_new_copy(axis));
 
 	return darray_size(self->axes) - 1;
 }
@@ -159,49 +156,112 @@ static void hkl_holder_update(HklHolder *self)
 	size_t i;
 
 	self->q = q0;
-	for(i=0; i<self->config->len; ++i)
-		hkl_quaternion_times_quaternion(&self->q,
-						&container_of(darray_item(self->geometry->axes,
-									  self->config->idx[i]),
-							      HklAxis, parameter)->q);
+	/*
+	 * The initial meaning of hkl_holder_update was to compute the
+	 * global rotation of the holder. The first holder contained
+	 * only centered rotations. Now that we have added also
+	 * translation, we stop this computation at the first non
+	 * rotation axis
+	 *
+	 * The right think to do should be to add an
+	 * HklVector hkl_holder_apply_transformation(const Hklholder, const HklVector *vector)
+	 * for every kind of transformation (translation, rotation, etc...)
+	 */
+	for(i=0; i<self->config->len; ++i){
+		const HklParameter *p;
+		const HklQuaternion *q;
+
+		p = darray_item(self->geometry->axes, self->config->idx[i]);
+		q = hkl_parameter_quaternion_get(p);
+		if(NULL == q)
+			break;
+		else
+			hkl_quaternion_times_quaternion(&self->q, q);
+	}
 }
 
-HklParameter *hkl_holder_add_rotation_axis(HklHolder *self,
-					   const char *name, double x, double y, double z)
+static HklParameter * hkl_holder_add_axis_if_not_present(const HklHolder *self, int idx)
 {
-	return hkl_holder_add_rotation_axis_with_punit(self, name, x, y, z, &hkl_unit_angle_deg);
-}
+	size_t i;
+	HklParameter *res = NULL;
 
-HklParameter *hkl_holder_add_rotation_axis_with_punit(HklHolder *self,
-						      const char *name, double x, double y, double z,
-						      const HklUnit *punit)
-{
-	HklParameter *axis = NULL;
-	size_t i, idx;
-	HklVector axis_v;
-
-	axis_v.data[0] = x;
-	axis_v.data[1] = y;
-	axis_v.data[2] = z;
-
-	idx = hkl_geometry_add_rotation(self->geometry, name, &axis_v, punit);
-
-	/* check that the axis is not already in the holder */
+	/* check if the axis was already in the geometry */
 	for(i=0; i<self->config->len; i++)
 		if (idx == self->config->idx[i])
 			return NULL;
 
-	axis = darray_item(self->geometry->axes, idx);
+	res = darray_item(self->geometry->axes, idx);
 	self->config->idx = realloc(self->config->idx, sizeof(*self->config->idx) * (self->config->len + 1));
 	self->config->idx[self->config->len++] = idx;
 
-	return axis;
+	return res;
+}
+
+HklParameter *hkl_holder_add_rotation(HklHolder *self,
+				      const char *name,
+				      double x, double y, double z,
+				      const HklUnit *punit)
+{
+	HklVector axis_v = {{x, y, z}};
+	HklParameter *axis = hkl_parameter_new_rotation(name, &axis_v, punit);
+	int idx = hkl_geometry_add_axis(self->geometry, axis);
+	hkl_parameter_free(axis);
+
+	return hkl_holder_add_axis_if_not_present(self, idx);
+}
+
+HklParameter *hkl_holder_add_rotation_with_origin(HklHolder *self,
+						  const char *name,
+						  double x, double y, double z,
+						  double ox, double oy, double oz,
+						  const HklUnit *punit)
+{
+	HklVector axis_v = {{x, y, z}};
+	HklVector origin = {{ox, oy, oz}};
+	HklParameter *axis = hkl_parameter_new_rotation_with_origin(name, &axis_v, &origin, punit);
+	int idx = hkl_geometry_add_axis(self->geometry, axis);
+	hkl_parameter_free(axis);
+
+	return hkl_holder_add_axis_if_not_present(self, idx);
+
+}
+
+
+HklParameter *hkl_holder_add_translation(HklHolder *self,
+					 const char *name,
+					 double x, double y, double z,
+					 const HklUnit *punit)
+{
+	HklVector axis_v = {{x, y, z}};
+	HklParameter *axis = hkl_parameter_new_translation(name, &axis_v, punit);
+	int idx = hkl_geometry_add_axis(self->geometry, axis);
+	hkl_parameter_free(axis);
+
+	return hkl_holder_add_axis_if_not_present(self, idx);
+}
+
+HklVector hkl_holder_transformation_apply(const HklHolder *self,
+					  const HklVector *v)
+{
+	size_t i;
+	HklVector res = *v;
+
+	/* for each axis from the end apply the transformation to the vector */
+	for(i=0;i<self->config->len;i++){
+		HklParameter *p = darray_item(self->geometry->axes,
+					      self->config->idx[self->config->len - 1 - i]);
+		res = hkl_parameter_transformation_apply(p, &res);
+	}
+
+	return res;
 }
 
 /***************/
 /* HklGeometry */
 /***************/
 
+const HklGeometryOperations hkl_geometry_operations_defaults = { HKL_GEOMETRY_OPERATIONS_DEFAULTS };
+
 /**
  * hkl_geometry_new: (skip)
  *
@@ -209,11 +269,13 @@ HklParameter *hkl_holder_add_rotation_axis_with_punit(HklHolder *self,
  *
  * Returns:
  **/
-HklGeometry *hkl_geometry_new(const HklFactory *factory)
+HklGeometry *hkl_geometry_new(const HklFactory *factory,
+			      const HklGeometryOperations *ops)
 {
 	HklGeometry *g = NULL;
 
 	g = HKL_MALLOC(HklGeometry);
+	g->ops = ops;
 
 	g->factory = factory;
 	hkl_source_init(&g->source, 1.54, 1, 0, 0);
@@ -237,13 +299,9 @@ HklGeometry *hkl_geometry_new_copy(const HklGeometry *src)
 	HklParameter **axis;
 	HklHolder **holder;
 
-	if(!src)
-		return self;
-
 	self = HKL_MALLOC(HklGeometry);
 
-	self->factory = src->factory;
-	self->source = src->source;
+	*self = *src;
 
 	/* copy the axes */
 	darray_init(self->axes);
@@ -299,6 +357,7 @@ int hkl_geometry_set(HklGeometry *self, const HklGeometry *src)
 	size_t i;
 
 	hkl_error(self->factory == src->factory);
+	hkl_error(self->ops == src->ops);
 
 	self->source = src->source;
 
@@ -812,7 +871,7 @@ int hkl_geometry_closest_from_geometry_with_range(HklGeometry *self,
 HklQuaternion hkl_geometry_sample_rotation_get(const HklGeometry *self,
 					       const HklSample *sample)
 {
-	return darray_item(self->holders, 0)->q;
+	return hkl_geometry_sample_holder_get(self, sample)->q;
 }
 
 /**
@@ -828,7 +887,7 @@ HklQuaternion hkl_geometry_sample_rotation_get(const HklGeometry *self,
 HklQuaternion hkl_geometry_detector_rotation_get(const HklGeometry *self,
 						 const HklDetector *detector)
 {
-	return darray_item(self->holders, detector->idx)->q;
+	return hkl_geometry_detector_holder_get(self, detector)->q;
 }
 
 
@@ -850,6 +909,29 @@ void hkl_geometry_fprintf(FILE *file, const HklGeometry *self)
 	}
 }
 
+HklHolder *hkl_geometry_sample_holder_get(const HklGeometry *self,
+					  const HklSample *sample)
+{
+	return self->ops->sample_holder_get(self, sample);
+}
+
+HklHolder *hkl_geometry_detector_holder_get(const HklGeometry *self,
+					    const HklDetector *detector)
+{
+	return self->ops->detector_holder_get(self, detector);
+}
+
+HklVector hkl_geometry_ki_get(const HklGeometry *self)
+{
+	return self->ops->ki_get(self);
+}
+
+HklVector hkl_geometry_kf_get(const HklGeometry *self,
+			      const HklDetector *detector)
+{
+	return self->ops->kf_get(self, detector);
+}
+
 /*******************/
 /* HklGeometryList */
 /*******************/
@@ -928,7 +1010,7 @@ void hkl_geometry_list_free(HklGeometryList *self)
  * set the geometry axes and copy it to the right geometries. We do
  * not gives the x len as it is equal to the self->axes_len.
  **/
-void hkl_geometry_list_add(HklGeometryList *self, HklGeometry *geometry)
+void hkl_geometry_list_add(HklGeometryList *self, const HklGeometry *geometry)
 {
 	HklGeometryListItem *item;
 
@@ -1079,22 +1161,13 @@ void hkl_geometry_list_fprintf(FILE *f, const HklGeometryList *self)
 			fprintf(f, "\n%d :", i++);
 			darray_foreach(axis, item->geometry->axes){
 				value = hkl_parameter_value_get(*axis, HKL_UNIT_DEFAULT);
-				if ((*axis)->punit)
-					fprintf(f, " % 18.15f %s", value, (*axis)->punit->repr);
-				else
-					fprintf(f, " % 18.15f", value);
+				fprintf(f, " % 18.15f %s", value, (*axis)->unit->repr);
 
 			}
 			fprintf(f, "\n   ");
 			darray_foreach(axis, item->geometry->axes){
-				value = hkl_parameter_value_get(*axis, HKL_UNIT_DEFAULT);
-				value = gsl_sf_angle_restrict_symm(value);
-				value *= hkl_unit_factor((*axis)->unit,
-							 (*axis)->punit);
-				if ((*axis)->punit)
-					fprintf(f, " % 18.15f %s", value, (*axis)->punit->repr);
-				else
-					fprintf(f, " % 18.15f", value);
+				value = hkl_parameter_value_get(*axis, HKL_UNIT_USER);
+				fprintf(f, " % 18.15f %s", value, (*axis)->punit->repr);
 			}
 			fprintf(f, "\n");
 		}
