@@ -14,7 +14,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2016 Synchrotron SOLEIL
+ * Copyright (C) 2003-2018 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -48,7 +48,7 @@ struct _HklParameter {
 	const HklParameterOperations *ops;
 };
 
-#define HKL_PARAMETER_DEFAULTS .name="dummy", .description="no description", .range={.min=0, .max=0}, ._value=0, .unit=NULL, .punit=NULL, .fit=TRUE, .changed=TRUE, .ops = &hkl_parameter_operations_defaults
+#define HKL_PARAMETER_DEFAULTS .name="dummy", .description="no description", .range={.min=-DBL_MAX, .max=DBL_MAX}, ._value=0, .unit=NULL, .punit=NULL, .fit=TRUE, .changed=TRUE, .ops = &hkl_parameter_operations_defaults
 
 #define HKL_PARAMETER_DEFAULTS_ANGLE HKL_PARAMETER_DEFAULTS, .range={.min=-M_PI, .max=M_PI}, .unit = &hkl_unit_angle_rad, .punit = &hkl_unit_angle_deg
 
@@ -83,6 +83,8 @@ struct _HklParameterOperations {
 	void                  (*fprintf)(FILE *f, const HklParameter *self);
 	const HklVector *     (*axis_v_get)(const HklParameter *self);
 	const HklQuaternion * (*quaternion_get)(const HklParameter *self);
+	int                   (*transformation_cmp)(const HklParameter *self, const HklParameter *p2);
+	HklVector             (*transformation_apply)(const HklParameter *self, const HklVector *v);
 };
 
 #define HKL_PARAMETER_OPERATIONS_DEFAULTS				\
@@ -97,7 +99,9 @@ struct _HklParameterOperations {
 		.is_valid_range = hkl_parameter_is_valid_real,		\
 		.fprintf = hkl_parameter_fprintf_real,			\
 		.axis_v_get = hkl_parameter_axis_v_get_real,		\
-		.quaternion_get = hkl_parameter_quaternion_get_real
+		.quaternion_get = hkl_parameter_quaternion_get_real,	\
+		.transformation_cmp = hkl_parameter_transformation_cmp_real, \
+		.transformation_apply = hkl_parameter_transformation_apply_real
 
 static inline HklParameter *hkl_parameter_copy_real(const HklParameter *self)
 {
@@ -203,6 +207,17 @@ static inline const HklQuaternion *hkl_parameter_quaternion_get_real(UNUSED cons
 	return NULL;
 }
 
+static inline int hkl_parameter_transformation_cmp_real(const HklParameter *self, const HklParameter *p2)
+{
+	return self->ops != p2->ops;
+}
+
+static inline HklVector hkl_parameter_transformation_apply_real(UNUSED const HklParameter *self,
+								const HklVector *v)
+{
+	return *v;
+}
+
 static NEEDED HklParameterOperations hkl_parameter_operations_defaults = {
 	HKL_PARAMETER_OPERATIONS_DEFAULTS,
 };
@@ -226,7 +241,13 @@ extern int hkl_parameter_is_valid(const HklParameter *self);
 
 extern int hkl_parameter_is_valid_range(const HklParameter *self);
 
-extern void hkl_parameter_fprintf(FILE *f, HklParameter *self);
+extern void hkl_parameter_fprintf(FILE *f, const HklParameter *self);
+
+extern int hkl_parameter_transformation_cmp(const HklParameter *self,
+					    const HklParameter *p2);
+
+extern HklVector hkl_parameter_transformation_apply(const HklParameter *self,
+						    const HklVector *v);
 
 /********************/
 /* HklParameterList */
