@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2016 Synchrotron SOLEIL
+ * Copyright (C) 2003-2018 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -373,7 +373,7 @@ int hkl_parameter_is_valid_range(const HklParameter *self)
  *
  * print into the #FILE f an #HklParameter
  **/
-void hkl_parameter_fprintf(FILE *f, HklParameter *self)
+void hkl_parameter_fprintf(FILE *f, const HklParameter *self)
 {
 	double factor = hkl_unit_factor(self->unit, self->punit);
 	if (self->punit)
@@ -425,3 +425,30 @@ const char *hkl_parameter_description_get(const HklParameter *self)
 {
 	return self->description;
 }
+
+/**
+ * hkl_parameter_transformation_cmp: (skip)
+ * @self: the this ptr
+ * @p2: the second parameter to test with
+ *
+ * Returns: if two parameter transformations are compatibles.
+ *          (0) compatible, (!= 0) not-compatible
+ **/
+int hkl_parameter_transformation_cmp(const HklParameter *self,
+				     const HklParameter *p2)
+{
+	return self->ops->transformation_cmp(self, p2);
+}
+
+/**
+ * hkl_parameter_transformation_apply: (skip)
+ * @self: the this ptr
+ * @v: the #HklVector to transform
+ *
+ * Returns: the transformed #HklVector
+ **/
+HklVector hkl_parameter_transformation_apply(const HklParameter *self,
+					     const HklVector *v)
+{
+	return self->ops->transformation_apply(self, v);
+}
