@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2016 Synchrotron SOLEIL
+ * Copyright (C) 2003-2018 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -36,12 +36,12 @@
 #include "hkl-matrix-private.h"         // for hkl_matrix_times_vector, etc
 #include "hkl-parameter-private.h"      // for _HklParameter, etc
 #include "hkl-pseudoaxis-auto-private.h"  // for CHECK_NAN, etc
+#include "hkl-pseudoaxis-common-private.h"
 #include "hkl-pseudoaxis-common-hkl-private.h"  // for HklEngineHkl
 #include "hkl-pseudoaxis-common-q-private.h"  // for HklEngineHkl
 #include "hkl-pseudoaxis-private.h"     // for _HklEngine, _HklMode, etc
 #include "hkl-quaternion-private.h"     // for hkl_quaternion_init, etc
 #include "hkl-sample-private.h"         // for _HklSample
-#include "hkl-source-private.h"         // for hkl_source_compute_ki
 #include "hkl-vector-private.h"         // for HklVector, etc
 #include "hkl.h"                        // for HklEngine, HklGeometry, etc
 #include "hkl/ccan/array_size/array_size.h"  // for ARRAY_SIZE
@@ -81,7 +81,7 @@ static int fit_detector_function(const gsl_vector *x, void *params, gsl_vector *
 
 	hkl_geometry_update(fitp->geometry);
 
-	hkl_detector_compute_kf(fitp->detector, fitp->geometry, &kf);
+	kf = hkl_geometry_kf_get(fitp->geometry, fitp->detector);
 
 	f->data[0] = fabs(fitp->kf0->data[0] - kf.data[0])
 		+ fabs(fitp->kf0->data[1] - kf.data[1])
@@ -105,8 +105,11 @@ static int fit_detector_function(const gsl_vector *x, void *params, gsl_vector *
 }
 
 
-static int fit_detector_position(HklMode *mode, HklGeometry *geometry,
-				 HklDetector *detector, HklVector *kf)
+static int fit_detector_position(HklMode *mode,
+				 HklGeometry *geometry,
+				 HklDetector *detector,
+				 const HklSample *sample,
+				 HklVector *kf)
 {
 	const char **axis_name;
 	HklDetectorFit params;
@@ -117,8 +120,8 @@ static int fit_detector_position(HklMode *mode, HklGeometry *geometry,
 	int status;
 	int res = FALSE;
 	int iter;
-	HklHolder *sample_holder = darray_item(geometry->holders, 0);
-	HklHolder *detector_holder = darray_item(geometry->holders, 1);
+	const HklHolder *sample_holder = hkl_geometry_sample_holder_get(geometry, sample);
+	const HklHolder *detector_holder = hkl_geometry_detector_holder_get(geometry, detector);
 
 	/* fit the detector part to find the position of the detector for a given kf */
 	/* FIXME for now the sample and detector holder are respectively the first and the second one */
@@ -230,21 +233,21 @@ static int fit_detector_position(HklMode *mode, HklGeometry *geometry,
 /* BEWARE, NOT the axis index in the geometry->axes */
 /* which is part of the axis_names of the mode */
 /* return -1 if there is no axes of the mode in the sample part of the geometry */
-static int get_last_axis_idx(HklGeometry *geometry, int holder_idx, const darray_string *axes)
+static int get_last_sample_axis_idx(HklGeometry *geometry, const HklSample *sample,
+				    const darray_string *axes)
 {
 	int last = -1;
 	const char **axis_name;
-	HklHolder *holder;
+	HklHolder *sample_holder = hkl_geometry_sample_holder_get(geometry, sample);
 
-	holder = darray_item(geometry->holders, holder_idx);
 	darray_foreach(axis_name, *axes){
 		size_t i;
 		size_t idx;
 
 		/* FIXME for now the sample holder is the first one */
 		idx = hkl_geometry_get_axis_idx_by_name(geometry, *axis_name);
-		for(i=0; i<holder->config->len; ++i)
-			if(idx == holder->config->idx[i]){
+		for(i=0; i<sample_holder->config->len; ++i)
+			if(idx == sample_holder->config->idx[i]){
 				last = last > (int)i ? last : (int)i;
 				break;
 			}
@@ -252,17 +255,23 @@ static int get_last_axis_idx(HklGeometry *geometry, int holder_idx, const darray
 	return last;
 }
 
-
-static int hkl_is_reachable(HklEngine *engine, double wavelength, GError **error)
+static const HklVector reciprocal_plan(const HklEngineHkl *engine_hkl)
 {
-	HklEngineHkl *engine_hkl = container_of(engine, HklEngineHkl, engine);
-	HklVector Hkl = {
+	const HklVector hkl = {
 		.data = {
 			engine_hkl->h->_value,
 			engine_hkl->k->_value,
 			engine_hkl->l->_value,
 		},
 	};
+	return hkl;
+}
+
+
+int hkl_is_reachable(HklEngine *engine, double wavelength, GError **error)
+{
+	const HklEngineHkl *engine_hkl = container_of(engine, HklEngineHkl, engine);
+	HklVector Hkl = reciprocal_plan(engine_hkl);
 
 	hkl_matrix_times_vector(&engine->sample->UB, &Hkl);
 	if (hkl_vector_norm2(&Hkl) > qmax(wavelength)){
@@ -307,35 +316,18 @@ int RUBh_minus_Q(double const x[], void *params, double f[])
 {
 	HklEngine *engine = params;
 	HklEngineHkl *engine_hkl = container_of(engine, HklEngineHkl, engine);
-	HklVector Hkl = {
-		.data = {
-			engine_hkl->h->_value,
-			engine_hkl->k->_value,
-			engine_hkl->l->_value,
-		},
-	};
-	HklVector ki, dQ;
-	HklHolder *sample_holder;
+	const HklVector Hkl = reciprocal_plan(engine_hkl);
 
 	/* update the workspace from x; */
 	set_geometry_axes(engine, x);
 
-	/* R * UB * h = Q */
-	/* for now the 0 holder is the sample holder. */
-	sample_holder = darray_item(engine->geometry->holders, 0);
-	hkl_matrix_times_vector(&engine->sample->UB, &Hkl);
-	hkl_vector_rotated_quaternion(&Hkl, &sample_holder->q);
-
-	/* kf - ki = Q */
-	hkl_source_compute_ki(&engine->geometry->source, &ki);
-	hkl_detector_compute_kf(engine->detector, engine->geometry, &dQ);
-	hkl_vector_minus_vector(&dQ, &ki);
-
-	hkl_vector_minus_vector(&dQ, &Hkl);
-
-	f[0] = dQ.data[0];
-	f[1] = dQ.data[1];
-	f[2] = dQ.data[2];
+	const struct HklHklWrite w = hkl_hkl_write(engine->geometry,
+						   engine->detector,
+						   engine->sample,
+						   &Hkl);
+	f[0] = w.dQ.data[0];
+	f[1] = w.dQ.data[1];
+	f[2] = w.dQ.data[2];
 
 	return GSL_SUCCESS;
 }
@@ -347,30 +339,16 @@ int hkl_mode_get_hkl_real(HklMode *self,
 			  HklSample *sample,
 			  GError **error)
 {
-	HklHolder *sample_holder;
-	HklMatrix RUB;
-	HklVector hkl, ki, Q;
 	HklEngineHkl *engine_hkl = container_of(engine, HklEngineHkl, engine);
 
 	/* update the geometry internals */
 	hkl_geometry_update(geometry);
 
-	/* R * UB */
-	/* for now the 0 holder is the sample holder. */
-	sample_holder = darray_item(geometry->holders, 0);
-	hkl_quaternion_to_matrix(&sample_holder->q, &RUB);
-	hkl_matrix_times_matrix(&RUB, &sample->UB);
+	const struct HklHklRead r = hkl_hkl_read(geometry, detector, sample);
 
-	/* kf - ki = Q */
-	hkl_source_compute_ki(&geometry->source, &ki);
-	hkl_detector_compute_kf(detector, geometry, &Q);
-	hkl_vector_minus_vector(&Q, &ki);
-
-	hkl_matrix_solve(&RUB, &hkl, &Q);
-
-	engine_hkl->h->_value = hkl.data[0];
-	engine_hkl->k->_value = hkl.data[1];
-	engine_hkl->l->_value = hkl.data[2];
+	engine_hkl->h->_value = r.hkl.data[0];
+	engine_hkl->k->_value = r.hkl.data[1];
+	engine_hkl->l->_value = r.hkl.data[2];
 
 	return TRUE;
 }
@@ -406,7 +384,7 @@ int hkl_mode_set_hkl_real(HklMode *self,
 
 	/* check that the mode allow to move a sample axis */
 	/* FIXME for now the sample holder is the first one */
-	last_axis = get_last_axis_idx(geometry, 0, &self->info->axes_w);
+	last_axis = get_last_sample_axis_idx(geometry, sample, &self->info->axes_w);
 	if(last_axis >= 0){
 		uint i;
 		const HklGeometryListItem *item;
@@ -444,18 +422,19 @@ int hkl_mode_set_hkl_real(HklMode *self,
 			HklVector cp = {{0}};
 			HklVector op = {{0}};
 			double angle;
-			HklGeometry *geom;
+			HklGeometry *geom = hkl_geometry_new_copy(item->geometry);
+			HklHolder *sample_holder = hkl_geometry_sample_holder_get(geom, sample);
 
 			geom = hkl_geometry_new_copy(item->geometry);
 
 			/* get the Q vector kf - ki */
-			hkl_detector_compute_kf(detector, geom, &q);
-			hkl_source_compute_ki(&geom->source, &ki);
+			ki = hkl_geometry_ki_get(geom);
+			q = hkl_geometry_kf_get(geom, detector);
 			hkl_vector_minus_vector(&q, &ki);
 
 			/* compute the current orientation of the last axis */
 			axis = container_of(darray_item(geom->axes,
-							darray_item(geom->holders, 0)->config->idx[last_axis]),
+							sample_holder->config->idx[last_axis]),
 					    HklAxis, parameter);
 			axis_v = axis->axis_v;
 			hkl_quaternion_init(&qr, 1, 0, 0, 0);
@@ -463,7 +442,7 @@ int hkl_mode_set_hkl_real(HklMode *self,
 				hkl_quaternion_times_quaternion(
 					&qr,
 					&container_of(darray_item(geom->axes,
-								  darray_item(geom->holders, 0)->config->idx[j]),
+								  sample_holder->config->idx[j]),
 						      HklAxis, parameter)->q);
 			hkl_vector_rotated_quaternion(&axis_v, &qr);
 
@@ -494,7 +473,7 @@ int hkl_mode_set_hkl_real(HklMode *self,
 			hkl_vector_add_vector(&kf2, &ki);
 
 			/* at the end we just need to solve numerically the position of the detector */
-			if(fit_detector_position(self, geom, detector, &kf2))
+			if(fit_detector_position(self, geom, detector, sample, &kf2))
 				hkl_geometry_list_add(engine->engines->geometries,
 						      geom);
 
@@ -508,6 +487,18 @@ int hkl_mode_set_hkl_real(HklMode *self,
 /* the double diffraction get set part */
 /***************************************/
 
+static HklVector reciprocal_plan2(const HklMode *mode)
+{
+	const HklVector hkl2 = {
+		.data = {
+			darray_item(mode->parameters, 0)->_value,
+			darray_item(mode->parameters, 1)->_value,
+			darray_item(mode->parameters, 2)->_value,
+		},
+	};
+	return hkl2;
+}
+
 /**
  * double_diffraction: (skip)
  * @x:
@@ -522,48 +513,20 @@ int _double_diffraction(double const x[], void *params, double f[])
 {
 	HklEngine *engine = params;
 	HklEngineHkl *engine_hkl = container_of(engine, HklEngineHkl, engine);
-	HklVector hkl = {
-		.data = {
-			engine_hkl->h->_value,
-			engine_hkl->k->_value,
-			engine_hkl->l->_value,
-		},
-	};
-	HklVector kf2;
-	HklVector ki;
-	HklVector dQ;
-	HklHolder *sample_holder;
+	const HklVector hkl1 = reciprocal_plan(engine_hkl);
+	const HklVector hkl2 = reciprocal_plan2(engine->mode);
 
 	/* update the workspace from x; */
 	set_geometry_axes(engine, x);
 
-	/* get the second hkl from the mode parameters */
-	hkl_vector_init(&kf2,
-			darray_item(engine->mode->parameters, 0)->_value,
-			darray_item(engine->mode->parameters, 1)->_value,
-			darray_item(engine->mode->parameters, 2)->_value);
-
-	/* R * UB * hkl = Q */
-	/* for now the 0 holder is the sample holder. */
-	sample_holder = darray_item(engine->geometry->holders, 0);
-	hkl_matrix_times_vector(&engine->sample->UB, &hkl);
-	hkl_vector_rotated_quaternion(&hkl, &sample_holder->q);
-
-	/* kf - ki = Q */
-	hkl_source_compute_ki(&engine->geometry->source, &ki);
-	hkl_detector_compute_kf(engine->detector, engine->geometry, &dQ);
-	hkl_vector_minus_vector(&dQ, &ki);
-	hkl_vector_minus_vector(&dQ, &hkl);
-
-	/* R * UB * hlk2 = Q2 */
-	hkl_matrix_times_vector(&engine->sample->UB, &kf2);
-	hkl_vector_rotated_quaternion(&kf2, &sample_holder->q);
-	hkl_vector_add_vector(&kf2, &ki);
-
-	f[0] = dQ.data[0];
-	f[1] = dQ.data[1];
-	f[2] = dQ.data[2];
-	f[3] = hkl_vector_norm2(&kf2) - hkl_vector_norm2(&ki);
+	const struct HklDoubleDiffractionWrite w = hkl_double_diffraction_write(engine->geometry,
+										engine->detector,
+										engine->sample,
+										&hkl1, &hkl2);
+	f[0] = w.hkl1W.dQ.data[0];
+	f[1] = w.hkl1W.dQ.data[1];
+	f[2] = w.hkl1W.dQ.data[2];
+	f[3] = hkl_vector_norm2(&w.kf2) - hkl_vector_norm2(&w.hkl2W.ki); /* 2nd diffraction condition */
 
 	return GSL_SUCCESS;
 }
@@ -587,7 +550,6 @@ int _double_diffraction_func(gsl_vector const *x, void *params, gsl_vector *f)
 	return  GSL_SUCCESS;
 }
 
-
 /******************************************/
 /* the psi_constant_vertical get set part */
 /******************************************/
@@ -604,59 +566,44 @@ int _double_diffraction_func(gsl_vector const *x, void *params, gsl_vector *f)
  **/
 int _psi_constant_vertical_func(gsl_vector const *x, void *params, gsl_vector *f)
 {
-	HklVector ki, kf, Q;
-	HklEngine *engine = params;
-
 	CHECK_NAN(x->data, x->size);
 
-	RUBh_minus_Q(x->data, params, f->data);
+	HklEngine *engine = params;
+	HklEngineHkl *engine_hkl = container_of(engine, HklEngineHkl, engine);
+	const HklVector hkl = reciprocal_plan(engine_hkl);
+	const HklVector hkl2 = reciprocal_plan2(engine->mode);
 
 	/* update the workspace from x; */
 	set_geometry_axes(engine, x->data);
 
-	/* kf - ki = Q */
-	hkl_source_compute_ki(&engine->geometry->source, &ki);
-	hkl_detector_compute_kf(engine->detector, engine->geometry, &kf);
-	Q = kf;
-	hkl_vector_minus_vector(&Q, &ki);
-
-	f->data[3] = darray_item(engine->mode->parameters, 3)->_value;
-
-	/* if |Q| > epsilon ok */
-	if(hkl_vector_normalize(&Q)){
-		HklVector hkl;
-		HklVector n;
-
-		/* compute n the intersection of the plan P(kf, ki) and PQ (normal Q) */
-		n = kf;
-		hkl_vector_vectorial_product(&n, &ki);
-		hkl_vector_vectorial_product(&n, &Q);
-
-		/* compute the hkl ref position in the laboratory */
-		/* referentiel. The geometry was already updated. */
-		/* FIXME for now the 0 holder is the sample holder. */
-		hkl.data[0] = darray_item(engine->mode->parameters, 0)->_value;
-		hkl.data[1] = darray_item(engine->mode->parameters, 1)->_value;
-		hkl.data[2] = darray_item(engine->mode->parameters, 2)->_value;
-		hkl_matrix_times_vector(&engine->sample->UB, &hkl);
-		hkl_vector_rotated_quaternion(&hkl,
-					      &darray_item(engine->geometry->holders, 0)->q);
-
-		/* project hkl on the plan of normal Q */
-		hkl_vector_project_on_plan(&hkl, &Q);
+	const struct HklPsiWrite w = hkl_psi_write(engine->geometry,
+						   engine->detector,
+						   engine->sample,
+						   &hkl, &hkl2);
+	if(w.status){
 #ifdef DEBUG
 		fprintf(stdout, "\n");
 		hkl_geometry_fprintf(stdout, engine->geometry);
 		fprintf(stdout, "\n");
 		fprintf(stdout, "%s n : <%f, %f, %f> hkl : <%f, %f, %f> Q : <%f, %f, %f> angle : %f\n",
 			__func__,
-			n.data[0], n.data[1], n.data[2],
-			hkl.data[0], hkl.data[1], hkl.data[2],
-			Q.data[0], Q.data[1], Q.data[2],
-			hkl_vector_oriented_angle(&n, &hkl, &Q) * HKL_RADTODEG);
+			w.n.data[0], w.n.data[1], w.n.data[2],
+			w.hkl.data[0], w.hkl.data[1], w.hkl.data[2],
+			w.Qn.data[0], w.Qn.data[1], w.Qn.data[2],
+			w.psi * HKL_RADTODEG);
 #endif
-		if(hkl_vector_norm2(&hkl) > HKL_EPSILON)
-			f->data[3] -=  hkl_vector_oriented_angle(&n, &hkl, &Q);
+		f->data[0] = w.hklW.dQ.data[0];
+		f->data[1] = w.hklW.dQ.data[1];
+		f->data[2] = w.hklW.dQ.data[2];
+		if(hkl_vector_norm2(&w.hkl2) > HKL_EPSILON)
+			f->data[3] = darray_item(engine->mode->parameters, 3)->_value - w.psi;
+		else
+			f->data[3] = 1;
+	}else{
+		f->data[0] = 1;
+		f->data[1] = 1;
+		f->data[2] = 1;
+		f->data[3] = 1;
 	}
 
 	return  GSL_SUCCESS;
@@ -681,17 +628,15 @@ int hkl_mode_initialized_set_psi_constant_vertical_real(HklMode *self,
 							int initialized,
 							GError **error)
 {
-	HklVector hkl;
-	HklVector ki, kf, Q, n;
-
 	if(initialized){
-		/* kf - ki = Q */
-		hkl_source_compute_ki(&geometry->source, &ki);
-		hkl_detector_compute_kf(detector, geometry, &kf);
-		Q = kf;
-		hkl_vector_minus_vector(&Q, &ki);
+		HklEngineHkl *engine_hkl = container_of(engine, HklEngineHkl, engine);
+		const HklVector hkl = reciprocal_plan(engine_hkl);
+		const HklVector hkl2 = reciprocal_plan2(engine->mode);
 
-		if (hkl_vector_is_null(&Q)){
+		const struct HklPsiWrite w = hkl_psi_write(geometry, detector, sample, &hkl, &hkl2);
+
+		/* kf - ki = Q */
+		if (hkl_vector_is_null(&w.hklW.Q)){
 			g_set_error(error,
 				    HKL_MODE_PSI_CONSTANT_VERTICAL_ERROR,
 				    HKL_MODE_PSI_CONSTANT_VERTICAL_ERROR_INITIALIZED_SET,
@@ -699,28 +644,7 @@ int hkl_mode_initialized_set_psi_constant_vertical_real(HklMode *self,
 				    "\nplease select a non-null hkl", self->info->name);
 			return FALSE;
 		}else{
-			/* needed for a problem of precision */
-			hkl_vector_normalize(&Q);
-
-			/* compute the intersection of the plan P(kf, ki) and PQ (normal Q) */
-			n = kf;
-			hkl_vector_vectorial_product(&n, &ki);
-			hkl_vector_vectorial_product(&n, &Q);
-
-			/* compute hkl in the laboratory referentiel */
-			/* the geometry was already updated in the detector compute kf */
-			/* for now the 0 holder is the sample holder */
-			hkl.data[0] = darray_item(self->parameters, 0)->_value;
-			hkl.data[1] = darray_item(self->parameters, 1)->_value;
-			hkl.data[2] = darray_item(self->parameters, 2)->_value;
-			hkl_matrix_times_vector(&sample->UB, &hkl);
-			hkl_vector_rotated_quaternion(&hkl,
-						      &darray_item(geometry->holders, 0)->q);
-
-			/* project hkl on the plan of normal Q */
-			hkl_vector_project_on_plan(&hkl, &Q);
-
-			if (hkl_vector_is_null(&hkl)){
+			if (hkl_vector_is_null(&w.hkl2)){
 				g_set_error(error,
 					    HKL_MODE_PSI_CONSTANT_VERTICAL_ERROR,
 					    HKL_MODE_PSI_CONSTANT_VERTICAL_ERROR_INITIALIZED_SET,
@@ -732,7 +656,7 @@ int hkl_mode_initialized_set_psi_constant_vertical_real(HklMode *self,
 				/* compute the angle beetween hkl and n and
 				 * store in in the fourth parameter */
 				if (!hkl_parameter_value_set(darray_item(self->parameters, 3),
-							     hkl_vector_oriented_angle(&n, &hkl, &Q),
+							     w.psi,
 							     HKL_UNIT_DEFAULT, error))
 					return FALSE;
 			}
@@ -796,8 +720,9 @@ static int hkl_mode_hkl_emergence_fixed_initialized_set_real(HklMode *self,
 							     GError **error)
 {
 	const HklModeAutoHklEmergenceFixed *mode = container_of(self, HklModeAutoHklEmergenceFixed, parent);
-	HklVector kf;
-	HklVector n = surface(mode);
+	const HklEngineHkl *engine_hkl = container_of(engine, HklEngineHkl, engine);
+	const HklVector hkl = reciprocal_plan(engine_hkl);
+	const HklVector n = surface(mode);
 
 	/* first check the parameters */
 	if (hkl_vector_is_null(&n)){
@@ -808,13 +733,9 @@ static int hkl_mode_hkl_emergence_fixed_initialized_set_real(HklMode *self,
 		return FALSE;
 	}
 
-	/* compute the orientation of the surface */
-	hkl_vector_rotated_quaternion(&n, &darray_item(geometry->holders, 0)->q);
-
-	hkl_detector_compute_kf(detector, geometry, &kf);
-
 	/* compute emergence and keep it */
-	mode->emergence->_value = _emergence(&n, &kf);
+	const struct HklEmergenceFixedWrite w = hkl_emergence_fixed_write(geometry, detector, sample, &hkl, &n);
+	mode->emergence->_value = w.emergence;
 
 	self->initialized = initialized;
 
@@ -824,24 +745,26 @@ static int hkl_mode_hkl_emergence_fixed_initialized_set_real(HklMode *self,
 
 int _emergence_fixed_func(const gsl_vector *x, void *params, gsl_vector *f)
 {
-	HklEngine *engine = params;
-	HklModeAutoHklEmergenceFixed *mode = container_of(engine->mode,
-							  HklModeAutoHklEmergenceFixed,
-							  parent);
-	HklGeometry *geometry = engine->geometry;
-	const HklDetector *detector = engine->detector;
-	HklVector n = surface(mode);
-	HklVector kf;
-
 	CHECK_NAN(x->data, x->size);
 
-	RUBh_minus_Q(x->data, params, f->data);
+	HklEngine *engine = params;
+	const HklEngineHkl *engine_hkl = container_of(engine, HklEngineHkl, engine);
+	const HklModeAutoHklEmergenceFixed *mode = container_of(engine->mode, HklModeAutoHklEmergenceFixed, parent);
+	const HklVector hkl = reciprocal_plan(engine_hkl);
+	const HklVector n = surface(mode);
 
-	/* compute the orientation of the surface */
-	hkl_vector_rotated_quaternion(&n, &darray_item(geometry->holders, 0)->q);
-	hkl_detector_compute_kf(detector, geometry, &kf);
+	/* update the workspace from x; */
+	set_geometry_axes(engine, x->data);
 
-	f->data[3] = expected_emergence(mode) - _emergence(&n, &kf);
+	const struct HklEmergenceFixedWrite w = hkl_emergence_fixed_write(engine->geometry,
+									  engine->detector,
+									  engine->sample,
+									  &hkl, &n);
+
+	f->data[0] = w.hklW.dQ.data[0];
+	f->data[1] = w.hklW.dQ.data[1];
+	f->data[2] = w.hklW.dQ.data[2];
+	f->data[3] = expected_emergence(mode) - w.emergence;
 
 	return  GSL_SUCCESS;
 }
