@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2016 Synchrotron SOLEIL
+ * Copyright (C) 2003-2018 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -86,9 +86,10 @@ static int hkl_mode_incidence_get_real(HklMode *base,
 	}
 
 	/* compute the orientation of the surface */
-	hkl_vector_rotated_quaternion(&n, &darray_item(geometry->holders, 0)->q);
+	const HklHolder *sample_holder = hkl_geometry_sample_holder_get(geometry, sample);
+	hkl_vector_rotated_quaternion(&n, &sample_holder->q);
 
-	hkl_source_compute_ki(&geometry->source, &ki);
+	ki = hkl_geometry_ki_get(geometry);
 	incidence = _incidence(&n, &ki);
 
 	hkl_vector_project_on_plan(&n, &ki);
@@ -136,6 +137,13 @@ HklMode *hkl_mode_incidence_new(const HklModeInfo *info)
 	return &self->parent;
 }
 
+static void hkl_engine_incidence_free_real(HklEngine *base)
+{
+	HklEngineIncidence *self=container_of(base, HklEngineIncidence, engine);
+	hkl_engine_release(&self->engine);
+	free(self);
+}
+
 HklEngine *hkl_engine_incidence_new(HklEngineList *engines)
 {
 	HklEngineIncidence *self;
@@ -155,6 +163,7 @@ HklEngine *hkl_engine_incidence_new(HklEngineList *engines)
 	};
 	static HklEngineOperations operations = {
 		HKL_ENGINE_OPERATIONS_DEFAULTS,
+		.free=hkl_engine_incidence_free_real,
 	};
 
 	self = HKL_MALLOC(HklEngineIncidence);
@@ -234,9 +243,10 @@ static int hkl_mode_emergence_get_real(HklMode *base,
 	}
 
 	/* compute the orientation of the surface */
-	hkl_vector_rotated_quaternion(&n, &darray_item(geometry->holders, 0)->q);
+	const HklHolder *sample_holder = hkl_geometry_sample_holder_get(geometry, sample);
+	hkl_vector_rotated_quaternion(&n, &sample_holder->q);
 
-	hkl_detector_compute_kf(detector, geometry, &kf);
+	kf = hkl_geometry_kf_get(geometry, detector);
 	emergence = _emergence(&n, &kf);
 
 	hkl_vector_project_on_plan(&n, &X);
@@ -270,6 +280,13 @@ HklMode *hkl_mode_emergence_new(const HklModeInfo *info)
 	return &self->parent;
 }
 
+static void hkl_engine_emergence_free_real(HklEngine *base)
+{
+	HklEngineEmergence *self=container_of(base, HklEngineEmergence, engine);
+	hkl_engine_release(&self->engine);
+	free(self);
+}
+
 HklEngine *hkl_engine_emergence_new(HklEngineList *engines)
 {
 	HklEngineEmergence *self;
@@ -289,6 +306,8 @@ HklEngine *hkl_engine_emergence_new(HklEngineList *engines)
 	};
 	static HklEngineOperations operations = {
 		HKL_ENGINE_OPERATIONS_DEFAULTS,
+		.free=hkl_engine_emergence_free_real,
+
 	};
 
 	self = HKL_MALLOC(HklEngineEmergence);
