@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2016 Synchrotron SOLEIL
+ * Copyright (C) 2003-2018 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -60,8 +60,8 @@ static void _tth2(HklGeometry *geometry, HklDetector *detector,
 		.data = {1, 0, 0},
 	};
 
-	hkl_source_compute_ki(&geometry->source, &ki);
-	hkl_detector_compute_kf(detector, geometry, &kf);
+	ki = hkl_geometry_ki_get(geometry);
+	kf = hkl_geometry_kf_get(geometry, detector);
 	*tth = hkl_vector_angle(&ki, &kf);
 
 	/* project kf on the x plan to compute alpha */
