@@ -14,7 +14,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2016 Synchrotron SOLEIL
+ * Copyright (C) 2003-2018 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -130,7 +130,7 @@ int hkl_engine_pseudo_axis_values_get(HklEngine *self,
 		g_set_error(error,
 			    HKL_ENGINE_ERROR,
 			    HKL_ENGINE_ERROR_PSEUDO_AXIS_VALUES_GET,
-			    "cannot get engine pseudo axes, wrong number of parameter (%d) given, (%d) expected\n",
+			    "cannot get engine pseudo axes, wrong number of parameter (%zd) given, (%zd) expected\n",
 			    n_values, darray_size(self->info->pseudo_axes));
 		return FALSE;
 	}
@@ -178,7 +178,7 @@ HklGeometryList *hkl_engine_pseudo_axis_values_set(HklEngine *self,
 		g_set_error(error,
 			    HKL_ENGINE_ERROR,
 			    HKL_ENGINE_ERROR_PSEUDO_AXIS_VALUES_SET,
-			    "cannot set engine pseudo axes, wrong number of parameter (%d) given, (%d) expected\n",
+			    "cannot set engine pseudo axes, wrong number of parameter (%zd) given, (%zd) expected\n",
 			    n_values,  darray_size(self->info->pseudo_axes));
 		goto out;
 	}
@@ -192,8 +192,8 @@ HklGeometryList *hkl_engine_pseudo_axis_values_set(HklEngine *self,
 		fprintf(stream, " %f", values[i]);
 	fprintf(stream, "], n_values: %d unit_type: %d, error: %p)", n_values, unit_type, error);
 
-	hkl_geometry_fprintf(stream, self->geometry);
-	hkl_sample_fprintf(stream, self->sample);
+	hkl_geometry_fprintf(stream, self->engines->geometry);
+	hkl_sample_fprintf(stream, self->engines->sample);
 	hkl_engine_fprintf(stream, self);
 #endif
 	for(size_t i=0; i<n_values; ++i){
@@ -362,8 +362,6 @@ const darray_string *hkl_engine_parameters_names_get(const HklEngine *self)
  * @unit_type: the unit type (default or user) of the returned value
  *
  * Get the engine parameters values
- *
- * return value: TRUE if succeded or FALSE otherwise.
  **/
 void hkl_engine_parameters_values_get(const HklEngine *self,
 				      double values[], size_t n_values,
