@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2016 Synchrotron SOLEIL
+ * Copyright (C) 2003-2018 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -99,6 +99,10 @@ static void hkl_sample_reflection_update(HklSampleReflection *self)
 {
 	HklVector ki;
 	HklQuaternion q;
+	const HklHolder *sample_holder = hkl_geometry_sample_holder_get(self->geometry,
+									self->sample);
+	const HklHolder *detector_holder = hkl_geometry_detector_holder_get(self->geometry,
+									    self->detector);
 
 	if(!self)
 		return;
@@ -107,11 +111,10 @@ static void hkl_sample_reflection_update(HklSampleReflection *self)
 	/* first Q from angles */
 	hkl_source_compute_ki(&self->geometry->source, &ki);
 	self->_hkl = ki;
-	hkl_vector_rotated_quaternion(&self->_hkl,
-				      &darray_item(self->geometry->holders, self->detector->idx)->q);
+	hkl_vector_rotated_quaternion(&self->_hkl, &detector_holder->q);
 	hkl_vector_minus_vector(&self->_hkl, &ki);
 
-	q = darray_item(self->geometry->holders, 0)->q;
+	q = sample_holder->q;
 	hkl_quaternion_conjugate(&q);
 	hkl_vector_rotated_quaternion(&self->_hkl, &q);
 }
@@ -334,10 +337,6 @@ HklSample* hkl_sample_new(const char *name)
 {
 	HklSample *self = NULL;
 
-	/* check parameters */
-	if(!name)
-		return self;
-
 	self = HKL_MALLOC(HklSample);
 
 	self->name = strdup(name);
@@ -380,10 +379,6 @@ HklSample *hkl_sample_new_copy(const HklSample *self)
 {
 	HklSample *dup = NULL;
 
-	/* check parameters */
-	if(!self)
-		return dup;
-
 	dup = HKL_MALLOC(HklSample);
 
 	dup->name = strdup(self->name);
@@ -407,9 +402,6 @@ HklSample *hkl_sample_new_copy(const HklSample *self)
  **/
 void hkl_sample_free(HklSample *self)
 {
-	if (!self)
-		return;
-
 	free(self->name);
 	hkl_lattice_free(self->lattice);
 	hkl_parameter_free(self->ux);
@@ -705,6 +697,9 @@ void hkl_sample_add_reflection(HklSample *self,
 			return;
 	}
 
+	reflection->sample = self;
+	hkl_sample_reflection_update(reflection);
+
 	list_add_tail(&self->reflections, &reflection->list);
 	self->n_reflections++;
 }
@@ -915,22 +910,18 @@ HklSampleReflection *hkl_sample_reflection_new(const HklGeometry *geometry,
 					       double h, double k, double l,
 					       GError **error)
 {
-	HklSampleReflection *self;
-
-	if (!geometry || !detector)
-		return NULL;
+	HklSampleReflection *self = NULL;
 
 	self = HKL_MALLOC(HklSampleReflection);
 
 	self->geometry = hkl_geometry_new_copy(geometry);
 	self->detector = hkl_detector_new_copy(detector);
+	self->sample = NULL;
 	self->hkl.data[0] = h;
 	self->hkl.data[1] = k;
 	self->hkl.data[2] = l;
 	self->flag = TRUE;
 
-	hkl_sample_reflection_update(self);
-
 	return self;
 }
 
