@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2016 Synchrotron SOLEIL
+ * Copyright (C) 2003-2018 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -24,23 +24,26 @@
 #include <tap/basic.h>
 #include <tap/hkl-tap.h>
 
+#include "hkl/ccan/generator/generator.h"
+#include "hkl-geometry-private.h"
+#include "hkl-trajectory-private.h"
+
 static void getter(void)
 {
 	int res = TRUE;
 	HklEngineList *engines;
 	HklEngine *engine;
-	const HklFactory *factory;
 	HklGeometry *geometry;
 	HklDetector *detector;
 	HklSample *sample;
+	struct Geometry gconf = E4ch(1.54, 0., 0., 0., 0.);
 
-	factory = hkl_factory_get_by_name("E4CH", NULL);
-	geometry = hkl_factory_create_new_geometry(factory);
-	sample = hkl_sample_new("test");
+	geometry = newGeometry(gconf);
+	engines = newEngines(gconf);
+	sample = newSample(cu);
 
 	detector = hkl_detector_factory_new(HKL_DETECTOR_TYPE_0D);
 
-	engines = hkl_factory_create_new_engine_list(factory);
 	hkl_engine_list_init(engines, geometry, detector, sample);
 
 	engine = hkl_engine_list_engine_get_by_name(engines, "hkl", NULL);
@@ -76,20 +79,18 @@ static void degenerated(void)
 	HklEngine *engine;
 	const char **mode;
 	const darray_string *modes;
-	const HklFactory *factory;
 	HklGeometry *geometry;
 	HklDetector *detector;
 	HklSample *sample;
+	struct Geometry gconf = E4ch(1.54, 0., 0., 0., 0.);
 
-	factory = hkl_factory_get_by_name("E4CH", NULL);
-	geometry = hkl_factory_create_new_geometry(factory);
-	sample = hkl_sample_new("test");
+	geometry = newGeometry(gconf);
+	engines = newEngines(gconf);
+	sample = newSample(cu);
 
 	detector = hkl_detector_factory_new(HKL_DETECTOR_TYPE_0D);
 
-	engines = hkl_factory_create_new_engine_list(factory);
 	hkl_engine_list_init(engines, geometry, detector, sample);
-
 	engine = hkl_engine_list_engine_get_by_name(engines, "hkl", NULL);
 	modes = hkl_engine_modes_names_get(engine);
 
@@ -138,25 +139,23 @@ static void psi_getter(void)
 	int res = TRUE;
 	HklEngineList *engines;
 	HklEngine *engine;
-	const HklFactory *factory;
 	HklGeometry *geometry;
 	HklDetector *detector;
 	HklSample *sample;
 	double hkl[3];
+	struct Geometry gconf = E4ch(1.54, 30., 0., 0., 60.);
 
-	factory = hkl_factory_get_by_name("E4CH", NULL);
-	geometry = hkl_factory_create_new_geometry(factory);
-	sample = hkl_sample_new("test");
+	geometry = newGeometry(gconf);
+	engines = newEngines(gconf);
+	sample = newSample(cu);
 
 	detector = hkl_detector_factory_new(HKL_DETECTOR_TYPE_0D);
 
-	engines = hkl_factory_create_new_engine_list(factory);
 	hkl_engine_list_init(engines, geometry, detector, sample);
 
 	engine = hkl_engine_list_engine_get_by_name(engines, "psi", NULL);
 
 	/* the getter part */
-	res &= DIAG(hkl_geometry_set_values_v(geometry, HKL_UNIT_USER, NULL, 30., 0., 0., 60.));
 	res &= DIAG(hkl_engine_initialized_set(engine, TRUE, NULL));
 
 	hkl[0] = 1, hkl[1] = 0, hkl[2] = 0;
@@ -201,26 +200,24 @@ static void psi_setter(void)
 	HklEngine *engine;
 	const darray_string *modes;
 	const char **mode;
-	const HklFactory *factory;
 	HklGeometry *geometry;
 	HklDetector *detector;
 	HklSample *sample;
 	static double hkl[] = {1, 0, 0};
+	struct Geometry gconf = E4ch(1.54, 30., 0., 0., 60.);
 
-	factory = hkl_factory_get_by_name("E4CH", NULL);
-	geometry = hkl_factory_create_new_geometry(factory);
-	sample = hkl_sample_new("test");
+	geometry = newGeometry(gconf);
+	engines = newEngines(gconf);
+	sample = newSample(cu);
 
 	detector = hkl_detector_factory_new(HKL_DETECTOR_TYPE_0D);
 
-	engines = hkl_factory_create_new_engine_list(factory);
 	hkl_engine_list_init(engines, geometry, detector, sample);
 
 	engine = hkl_engine_list_engine_get_by_name(engines, "psi", NULL);
 	modes = hkl_engine_modes_names_get(engine);
 
 	/* the init part */
-	res &= DIAG(hkl_geometry_set_values_v(geometry, HKL_UNIT_USER, NULL, 30., 0., 0., 60.));
 	res &= DIAG(hkl_engine_parameters_values_set(engine, hkl, ARRAY_SIZE(hkl),
 						     HKL_UNIT_DEFAULT, NULL));
 	res &= DIAG(hkl_engine_initialized_set(engine, TRUE, NULL));
@@ -263,25 +260,23 @@ static void q(void)
 	HklEngine *engine;
 	const darray_string *modes;
 	const char **mode;
-	const HklFactory *factory;
 	HklGeometry *geometry;
 	HklDetector *detector;
 	HklSample *sample;
+	struct Geometry gconf = E4ch(1.54, 30., 0., 0., 60.);
 
-	factory = hkl_factory_get_by_name("E4CH", NULL);
-	geometry = hkl_factory_create_new_geometry(factory);
-	sample = hkl_sample_new("test");
+	geometry = newGeometry(gconf);
+	engines = newEngines(gconf);
+	sample = newSample(cu);
 
 	detector = hkl_detector_factory_new(HKL_DETECTOR_TYPE_0D);
 
-	engines = hkl_factory_create_new_engine_list(factory);
 	hkl_engine_list_init(engines, geometry, detector, sample);
 
 	engine = hkl_engine_list_engine_get_by_name(engines, "q", NULL);
 	modes = hkl_engine_modes_names_get(engine);
 
 	/* the init part */
-	res &= DIAG(hkl_geometry_set_values_v(geometry, HKL_UNIT_USER, NULL, 30., 0., 0., 60.));
 	res &= DIAG(hkl_engine_initialized_set(engine, TRUE, NULL));
 
 	darray_foreach(mode, *modes){
@@ -320,21 +315,20 @@ static void hkl_psi_constant_horizontal(void)
 	int res = TRUE;
 	HklEngineList *engines;
 	HklEngine *engine;
-	const HklFactory *factory;
 	HklGeometry *geometry;
 	HklGeometryList *geometries;
 	HklDetector *detector;
 	HklSample *sample;
 	static double hkl[] = {1, 0, 1};
 	static double hkl2[] = {1, 1, 0};
+	struct Geometry gconf = E4ch(1.54, 30., 0., 0., 60.);
 
-	factory = hkl_factory_get_by_name("E4CH", NULL);
-	geometry = hkl_factory_create_new_geometry(factory);
-	sample = hkl_sample_new("test");
+	geometry = newGeometry(gconf);
+	engines = newEngines(gconf);
+	sample = newSample(cu);
 
 	detector = hkl_detector_factory_new(HKL_DETECTOR_TYPE_0D);
 
-	engines = hkl_factory_create_new_engine_list(factory);
 	hkl_engine_list_init(engines, geometry, detector, sample);
 
 	engine = hkl_engine_list_engine_get_by_name(engines, "hkl", NULL);
@@ -342,7 +336,6 @@ static void hkl_psi_constant_horizontal(void)
 	res &= DIAG(hkl_engine_current_mode_set(engine, "psi_constant", NULL));
 
 	/* the init part */
-	res &= DIAG(hkl_geometry_set_values_v(geometry, HKL_UNIT_USER, NULL, 30., 0., 0., 60.));
 	res &= DIAG(hkl_engine_parameters_values_set(engine, hkl2, ARRAY_SIZE(hkl2),
 						     HKL_UNIT_DEFAULT, NULL));
 	res &= DIAG(hkl_engine_initialized_set(engine, TRUE, NULL));
@@ -369,9 +362,37 @@ static void hkl_psi_constant_horizontal(void)
 	hkl_geometry_free(geometry);
 }
 
+static void petra3_p01(void)
+{
+	int res = TRUE;
+	HklGeometryList *solutions;
+
+	struct Sample sample = {
+		.name = "Sample",
+		.lattice = Tetragonal(5.4, 11.9),
+		.ux = -90 * HKL_DEGTORAD,
+		.uy = 9 * HKL_DEGTORAD,
+		.uz = -45 * HKL_DEGTORAD,
+	};
+
+	struct Geometry gconfig = E4ch(4.3687,
+				       0., 0., 6., 0.);
+
+	struct Mode mode = ModeHklE4CHConstantPhi;
+
+	/* move between each step */
+	struct Trajectory tconfig1 = TrajectoryHklFromTo(0, 0, 4, 1, 1, 4, 30, mode);
+	solutions = Trajectory_solve(tconfig1, gconfig, sample, TRUE);
+	res &= DIAG(NULL != solutions);
+	hkl_geometry_list_fprintf(stdout, solutions);
+	hkl_geometry_list_free(solutions);
+
+	ok(res == TRUE, __func__);
+}
+
 int main(void)
 {
-	plan(6);
+	plan(7);
 
 	getter();
 	degenerated();
@@ -379,6 +400,7 @@ int main(void)
 	psi_setter();
 	q();
 	hkl_psi_constant_horizontal();
+	petra3_p01();
 
 	return 0;
 }
