@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2016 Synchrotron SOLEIL
+ * Copyright (C) 2003-2018 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -63,18 +63,17 @@ static void getter(void)
 	int res = TRUE;
 	HklEngineList *engines;
 	HklEngine *engine;
-	const HklFactory *factory;
 	HklGeometry *geometry;
 	HklDetector *detector;
 	HklSample *sample;
+	struct Geometry gconf = E6c(1.54, 0., 30., 0., 0., 0., 60.);
 
-	factory = hkl_factory_get_by_name("E6C", NULL);
-	geometry = hkl_factory_create_new_geometry(factory);
-	sample = hkl_sample_new("test");
+	geometry = newGeometry(gconf);
+	engines = newEngines(gconf);
+	sample = newSample(cu);
 
 	detector = hkl_detector_factory_new(HKL_DETECTOR_TYPE_0D);
 
-	engines = hkl_factory_create_new_engine_list(factory);
 	hkl_engine_list_init(engines, geometry, detector, sample);
 
 	engine = hkl_engine_list_engine_get_by_name(engines, "hkl", NULL);
@@ -110,19 +109,18 @@ static void degenerated(void)
 	HklEngine *engine;
 	const darray_string *modes;
 	const char **mode;
-	const HklFactory *factory;
 	HklGeometry *geometry;
 	HklDetector *detector;
 	HklSample *sample;
 	static double hkl[] = {0, 0, 1};
+	struct Geometry gconf = E6c(1.54, 0., 30., 0., 0., 0., 60.);
 
-	factory = hkl_factory_get_by_name("E6C", NULL);
-	geometry = hkl_factory_create_new_geometry(factory);
-	sample = hkl_sample_new("test");
+	geometry = newGeometry(gconf);
+	engines = newEngines(gconf);
+	sample = newSample(cu);
 
 	detector = hkl_detector_factory_new(HKL_DETECTOR_TYPE_0D);
 
-	engines = hkl_factory_create_new_engine_list(factory);
 	hkl_engine_list_init(engines, geometry, detector, sample);
 
 	engine = hkl_engine_list_engine_get_by_name(engines, "hkl", NULL);
@@ -175,25 +173,23 @@ static void q2(void)
 	HklEngine *engine;
 	const char **mode;
 	const darray_string *modes;
-	const HklFactory *factory;
 	HklGeometry *geometry;
 	HklDetector *detector;
 	HklSample *sample;
+	struct Geometry gconf = E6c(1.54, 0., 30., 0., 0., 0., 60.);
 
-	factory = hkl_factory_get_by_name("E6C", NULL);
-	geometry = hkl_factory_create_new_geometry(factory);
-	sample = hkl_sample_new("test");
+	geometry = newGeometry(gconf);
+	engines = newEngines(gconf);
+	sample = newSample(cu);
 
 	detector = hkl_detector_factory_new(HKL_DETECTOR_TYPE_0D);
 
-	engines = hkl_factory_create_new_engine_list(factory);
 	hkl_engine_list_init(engines, geometry, detector, sample);
 
 	engine = hkl_engine_list_engine_get_by_name(engines, "q2", NULL);
 	modes = hkl_engine_modes_names_get(engine);
 
 	/* the init part */
-	res &= DIAG(hkl_geometry_set_values_v(geometry, HKL_UNIT_USER, NULL, 0., 30., 0., 0., 0., 60.));
 	res &= DIAG(hkl_engine_initialized_set(engine, TRUE, NULL));
 
 	darray_foreach(mode, *modes){
@@ -237,34 +233,25 @@ static void petra3(void)
 	HklEngineList *engines;
 	HklEngine *hkl;
 	HklEngine *psi;
-	const HklFactory *factory;
 	HklGeometry *geometry;
 	HklGeometryList *geometries;
 	HklDetector *detector;
 	HklSample *sample;
-	HklLattice *lattice;
-	HklMatrix *U;
+	struct Sample sconf = {
+		.name = "test",
+		.lattice = Cubic(7.813),
+		.ux = -112.5 * HKL_DEGTORAD,
+		.uy = -87.84 * HKL_DEGTORAD,
+		.uz = 157.48 * HKL_DEGTORAD,
+	};
+	struct Geometry gconf = E6c(2.033, 0., 30., 0., 0., 0., 60.);
 
-	factory = hkl_factory_get_by_name("E6C", NULL);
-	geometry = hkl_factory_create_new_geometry(factory);
-	res &= DIAG(hkl_geometry_wavelength_set(geometry, 2.033, HKL_UNIT_DEFAULT, NULL));
-
-	sample = hkl_sample_new("test");
-	lattice = hkl_lattice_new(7.813, 7.813, 7.813,
-				  90*HKL_DEGTORAD, 90*HKL_DEGTORAD, 90*HKL_DEGTORAD,
-				  NULL);
-	hkl_sample_lattice_set(sample, lattice);
-	hkl_lattice_free(lattice);
-
-	U = hkl_matrix_new_euler(-112.5 * HKL_DEGTORAD,
-				 -87.84 * HKL_DEGTORAD,
-				 157.48 * HKL_DEGTORAD);
-	hkl_sample_U_set(sample, U, NULL);
-	hkl_matrix_free(U);
+	geometry = newGeometry(gconf);
+	engines = newEngines(gconf);
+	sample = newSample(sconf);
 
 	detector = hkl_detector_factory_new(HKL_DETECTOR_TYPE_0D);
 
-	engines = hkl_factory_create_new_engine_list(factory);
 	hkl_engine_list_init(engines, geometry, detector, sample);
 
 	/* set the psi pseudo axis */
@@ -313,17 +300,22 @@ static void petra3_2(void)
 	HklEngineList *engines;
 	HklEngine *hkl;
 	HklEngine *psi;
-	const HklFactory *factory;
 	const HklGeometryListItem *item;
 	HklGeometry *geometry;
 	HklGeometryList *geometries;
 	HklDetector *detector;
 	HklSample *sample;
-	HklLattice *lattice;
-	HklMatrix *U;
 	double PSI;
 	double hkl_p[4];
 	double psi_p[3];
+	struct Sample sconf = {
+		.name = "test",
+		.lattice = Cubic(5.1),
+		.ux = -90.0 * HKL_DEGTORAD,
+		.uy = 0.0 * HKL_DEGTORAD,
+		.uz = -90.0 * HKL_DEGTORAD,
+	};
+	struct Geometry gconf = E6c(1.0332035, 0., 30., 0., 0., 0., 60.);
 
 	/* Wavelength 1.0332035 */
 	/* Mode       psi_constant_vertical */
@@ -334,25 +326,13 @@ static void petra3_2(void)
 	/* A 5.1 B 5.1 C 5.1  */
 	/* Alpha 90 Beta 90 Gamma 90  */
 
-	factory = hkl_factory_get_by_name("E6C", NULL);
-	geometry = hkl_factory_create_new_geometry(factory);
-	res &= DIAG(hkl_geometry_wavelength_set(geometry, 1.0332035, HKL_UNIT_DEFAULT, NULL));
+	geometry = newGeometry(gconf);
+	engines = newEngines(gconf);
 
-	sample = hkl_sample_new("test");
-	lattice = hkl_lattice_new(5.1, 5.1, 5.1,
-				  90*HKL_DEGTORAD, 90*HKL_DEGTORAD, 90*HKL_DEGTORAD,
-				  NULL);
-	hkl_sample_lattice_set(sample, lattice);
-	hkl_lattice_free(lattice);
-	U = hkl_matrix_new_euler(-90.0 * HKL_DEGTORAD,
-				 0.0 * HKL_DEGTORAD,
-				 -90.0 * HKL_DEGTORAD);
-	hkl_sample_U_set(sample, U, NULL);
-	hkl_matrix_free(U);
+	sample = newSample(sconf);
 
 	detector = hkl_detector_factory_new(HKL_DETECTOR_TYPE_0D);
 
-	engines = hkl_factory_create_new_engine_list(factory);
 	hkl_engine_list_init(engines, geometry, detector, sample);
 
 	/* set the hkl pseudo axis in psi_constant_vertical */
