@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2016 Synchrotron SOLEIL
+ * Copyright (C) 2003-2018 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -30,19 +30,18 @@ static void degenerated(void)
 	HklEngine *engine;
 	const darray_string *modes;
 	const char **mode;
-	const HklFactory *factory;
 	HklGeometry *geometry;
 	HklDetector *detector;
 	HklSample *sample;
 	static double hkl[] = {0, 1, 0};
+	struct Geometry gconf = K4cv(1.54, 30., 0., 0., 60.);
 
-	factory = hkl_factory_get_by_name("K4CV", NULL);
-	geometry = hkl_factory_create_new_geometry(factory);
-	sample = hkl_sample_new("test");
+	geometry = newGeometry(gconf);
+	engines = newEngines(gconf);
+	sample = newSample(cu);
 
 	detector = hkl_detector_factory_new(HKL_DETECTOR_TYPE_0D);
 
-	engines = hkl_factory_create_new_engine_list(factory);
 	hkl_engine_list_init(engines, geometry, detector, sample);
 
 	engine = hkl_engine_list_engine_get_by_name(engines, "hkl", NULL);
@@ -95,19 +94,18 @@ static void eulerians(void)
 	HklEngine *engine;
 	const darray_string *modes;
 	const char **mode;
-	const HklFactory *factory;
 	HklGeometry *geometry;
 	HklDetector *detector;
 	HklSample *sample;
 	static double eulerians[] = {0., 90 * HKL_DEGTORAD, 0.};
+	struct Geometry gconf = K4cv(1.54, 0., 0., 0., 0.);
 
-	factory = hkl_factory_get_by_name("K4CV", NULL);
-	geometry = hkl_factory_create_new_geometry(factory);
-	sample = hkl_sample_new("test");
+	geometry = newGeometry(gconf);
+	engines = newEngines(gconf);
+	sample = newSample(cu);
 
 	detector = hkl_detector_factory_new(HKL_DETECTOR_TYPE_0D);
 
-	engines = hkl_factory_create_new_engine_list(factory);
 	hkl_engine_list_init(engines, geometry, detector, sample);
 
 	engine = hkl_engine_list_engine_get_by_name(engines, "eulerians", NULL);
@@ -170,18 +168,17 @@ static void q(void)
 	HklEngine *engine;
 	const darray_string *modes;
 	const char **mode;
-	const HklFactory *factory;
 	HklGeometry *geometry;
 	HklDetector *detector;
 	HklSample *sample;
+	struct Geometry gconf = K4cv(1.54, 30., 0., 0., 60.);
 
-	factory = hkl_factory_get_by_name("K4CV", NULL);
-	geometry = hkl_factory_create_new_geometry(factory);
-	sample = hkl_sample_new("test");
+	geometry = newGeometry(gconf);
+	engines = newEngines(gconf);
+	sample = newSample(cu);
 
 	detector = hkl_detector_factory_new(HKL_DETECTOR_TYPE_0D);
 
-	engines = hkl_factory_create_new_engine_list(factory);
 	hkl_engine_list_init(engines, geometry, detector, sample);
 
 	engine = hkl_engine_list_engine_get_by_name(engines, "q", NULL);
