@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2016 Synchrotron SOLEIL
+ * Copyright (C) 2003-2018 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -28,44 +28,31 @@ static void solution(void)
 	int res = TRUE;
 	HklEngineList *engines;
 	HklEngine *engine;
-	const HklFactory *factory;
 	HklGeometry *geometry;
 	HklGeometryList *geometries;
 	HklDetector *detector;
 	HklSample *sample;
-	HklLattice *lattice;
 	static double hkl[] = {1, 1, 0};
-	HklMatrix *U;
+	static struct Sample sconf = {
+		.name = "test",
+		.lattice = Cubic(5.432),
+		.ux = -90.0 * HKL_DEGTORAD,
+		.uy = 0.0  * HKL_DEGTORAD,
+		.uz = 0.0  * HKL_DEGTORAD,
+	};
+	struct Geometry gconf = Zaxis(0.842, 1., 0., 0., 0.);
 
-	/* get the geometry and set the source */
-	factory = hkl_factory_get_by_name("ZAXIS", NULL);
-	geometry = hkl_factory_create_new_geometry(factory);
-	res &= DIAG(hkl_geometry_wavelength_set(geometry, 0.842, HKL_UNIT_DEFAULT, NULL));
-
-	/* set up the sample */
-	sample = hkl_sample_new("test");
-	lattice = hkl_lattice_new(5.432, 5.432, 5.432,
-				  90 * HKL_DEGTORAD,
-				  90 * HKL_DEGTORAD,
-				  90 * HKL_DEGTORAD,
-				  NULL);
-	hkl_sample_lattice_set(sample, lattice);
-	U = hkl_matrix_new_euler(-90*HKL_DEGTORAD, 0, 0);
-	hkl_sample_U_set(sample, U, NULL);
-	hkl_lattice_free(lattice);
-	hkl_matrix_free(U);
+	geometry = newGeometry(gconf);
+	engines = newEngines(gconf);
+	sample = newSample(sconf);
 
 	/* use a 0D detector */
 	detector = hkl_detector_factory_new(HKL_DETECTOR_TYPE_0D);
 
 	/* select the hkl pseudo axis */
-	engines = hkl_factory_create_new_engine_list(factory);
 	hkl_engine_list_init(engines, geometry, detector, sample);
 	engine = hkl_engine_list_engine_get_by_name(engines, "hkl", NULL);
 
-	/* the init part must succed */
-	res &= DIAG(hkl_geometry_set_values_v(geometry, HKL_UNIT_USER, NULL, 1., 0., 0., 0.));
-
 	/* compute the 1 1 0 */
 	geometries = hkl_engine_pseudo_axis_values_set(engine, hkl, ARRAY_SIZE(hkl),
 						       HKL_UNIT_DEFAULT, NULL);
